.. PySpike documentation master file, created by
   sphinx-quickstart on Thu Oct 16 15:56:58 2014.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

.. include:: ../Readme.rst

Reference
===================================

.. toctree::
   :maxdepth: 2

   pyspike

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

